%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is a MATLAB m-file that calculates the component values for a
% Peak Current Mode Controller utilizing the k factor method introduced in 
% Chapter 4 of Power Electronics a First Course by Dr. Ned Mohan.
% This is a file prepared by Dr. Seunghyun Chun @ California Baptist
% University ECE Department (schun@calbaptist.edu) for the use of the 
% Consortium of Universities for Sustainable Power(CUSP) members teaching 
% the Power Electronics course.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The section below requires you to manually input the values according to your
% parameters.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fc = 5000; % Crossover frequency, This is in Hz

powerstage_gain_at_fc = -29.33; % |Gps(s)||fc,  This is in dB, Obtain this from pspice simulation
powerstage_phase_at_fc = -90; %<Gps(s)|fc, This is in degrees. Obtain this from pspice simulation
target_phase_margin = 60; %This is in degrees
R1 = 10000 %This in ohms

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% Everthing below is generated automatically%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Gps_mag = db2mag(powerstage_gain_at_fc);
phase_boost = -90 + target_phase_margin - powerstage_phase_at_fc; % phi_boost, This is in degrees
K_boost = tand(45+phase_boost/2);
zero_freq = 2*pi*fc/K_boost; % wz, This is in rad/s
pole_freq = 2*pi*fc*K_boost; % wp, This is in rad/s

Control_gain_at_fc = 1/Gps_mag; %|Gc(s)||fc

kc = zero_freq/Gps_mag;


C2 = zero_freq/(kc*pole_freq*R1)%This in Farats
C1 = C2*(pole_freq/zero_freq-1)%This in Farats
R2 = 1/(zero_freq*C1)%This in ohms

%Generate Bode plot of designed controller using MATLAB Control Toolbox
s=tf('s');
H = kc*(1+s/zero_freq)/(s*(1+s/pole_freq));
bode(H)
title('Bode plot of the designed Peak Current Mode Controller')
grid on


