%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is a MATLAB m-file that calculates the component values for a
% Voltage Mode Controller utilizing the k factor method introduced in 
% Chapter 4 of Power Electronics a First Course by Dr. Ned Mohan.
% This is a file prepared by Dr. Seunghyun Chun @ California Baptist
% University ECE Department (schun@calbaptist.edu) for the use of the 
% Consortium of Universities for Sustainable Power(CUSP) members teaching 
% the Power Electronics course.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The section below requires you to manually input the values according to your
% parameters.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fc = 1000; % Crossover frequency, This is in Hz
PWM_gain = 1/1.8;%|Gpwm(s)||fc, 1.8 is the value of the valley to peak of the sawtooth waveform.
kFB = 0.2;%Voltage_Sening_Network_gain

powerstage_gain_at_fc = 24.969; % |Gps(s)||fc,  This is in dB, Obtain this from pspice simulation
powerstage_phase_at_fc = -140.630; %<Gps(s)|fc, This is in degrees. Obtain this from pspice simulation
target_phase_margin = 60; %This is in degrees
R1 = 100000 %This in ohms

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% Everthing below is generated automatically%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Gps_mag = db2mag(powerstage_gain_at_fc);
phase_boost = -90 + target_phase_margin - powerstage_phase_at_fc; % phi_boost, This is in degrees
K_boost = tand(45+phase_boost/4);
zero_freq = 2*pi*fc/K_boost; % wz, This is in rad/s
pole_freq = 2*pi*fc*K_boost; % wp, This is in rad/s

Control_gain_at_fc = 1/(PWM_gain*kFB*Gps_mag); %|Gc(s)||fc

kc = Control_gain_at_fc * zero_freq/K_boost;


C2 = zero_freq/(kc*pole_freq*R1)%This in Farats
C1 = C2*(pole_freq/zero_freq-1)%This in Farats
R2 = 1/(zero_freq*C1)%This in ohms
R3 = R1/(pole_freq/zero_freq-1)%This in ohms
C3 = 1/(pole_freq*R3)%This in Farats

%Generate Bode plot of designed controller using MATLAB Control Toolbox
s=tf('s');
H = kc*(1+s/zero_freq)^2/(s*(1+s/pole_freq)^2);
bode(H)
title('Bode plot of the designed Voltage Mode Controller')
grid on


